@@ -51,18 +51,17 @@ class Users(object):
 		#
 	def create(self,
 		# required:
-		name=None,
 		email=None,
 		password=None,
 		verify_password=None,
 		# optionals:
+		name=None,
 		phone_number=None,
 		photo_url=None,
 	):
 
 		# check parameters.
 		response = r3sponse.check_parameters(empty_value=None, parameters={
-			"name":name,
 			"email":email,
 			"password":password,
 			"verify_password":verify_password,
@@ -98,6 +97,7 @@ class Users(object):
 			return r3sponse.success_response(f"Successfully created user [{email}].", {
 				"user":user,
 				"uid":user.uid,
+				"email":user.email,
 			})
 		else:
 			return r3sponse.error_response(f"Failed to create user [{email}], error: {error}")
