@@ -19,10 +19,11 @@ class users():
 			# get parameters.
 			parameters, response = r3sponse.get_request_parameters(request, [
 				"email",
-				"name",
 				"password",
 				"verify_password",])
 			if response["error"] != None: return response
+			optional_parameters, _ = r3sponse.get_request_parameters(request, [
+				"name",], optional=True)
 
 			# check firebase set.
 			if firebase == None:
@@ -30,7 +31,7 @@ class users():
 
 			# make request.
 			response = firebase.users.create(
-				name=parameters["name"],
+				name=optional_parameters["name"],
 				email=parameters["email"],
 				password=parameters["password"],
 				verify_password=parameters["verify_password"],
